@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Distribution.Client.Freeze
@@ -54,8 +55,10 @@ import Distribution.Verbosity
 import Control.Monad
          ( when )
 import qualified Data.ByteString.Lazy.Char8 as BS.Char8
+#if !MIN_VERSION_base(4,8,0)
 import Data.Monoid
          ( mempty )
+#endif
 import Data.Version
          ( showVersion )
 import Distribution.Version
