@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      :  Distribution.Client.Sandbox
@@ -104,7 +105,9 @@ import Data.Char                              ( ord )
 import Data.IORef                             ( newIORef, writeIORef, readIORef )
 import Data.List                              ( delete, foldl' )
 import Data.Maybe                             ( fromJust, fromMaybe )
+#if !MIN_VERSION_base(4,8,0)
 import Data.Monoid                            ( mempty, mappend )
+#endif
 import Data.Word                              ( Word32 )
 import Numeric                                ( showHex )
 import System.Directory                       ( createDirectory
@@ -595,10 +598,10 @@ reinstallAddSourceDeps verbosity configFlags' configExFlags
       die' message = die (message ++ installFailedInSandbox)
       -- TODO: use a better error message, remove duplication.
       installFailedInSandbox =
-        "Note: when using a sandbox, all packages are required to have \
-        \consistent dependencies. \
-        \Try reinstalling/unregistering the offending packages or \
-        \recreating the sandbox."
+        "Note: when using a sandbox, all packages are required to have "
+        ++ "consistent dependencies. "
+        ++ "Try reinstalling/unregistering the offending packages or "
+        ++ "recreating the sandbox."
       logMsg message rest = debugNoWrap verbosity message >> rest
 
       topHandler' = topHandlerWith $ \_ -> do
