@@ -3,8 +3,11 @@
 
 module Distribution.Client.Upload (check, upload, report) where
 
+import qualified Data.ByteString.Lazy.Char8 as B (concat, length, pack, readFile, unpack)
+import           Data.ByteString.Lazy.Char8 (ByteString)
+
 import Distribution.Client.Types (Username(..), Password(..),Repo(..),RemoteRepo(..))
-import Distribution.Client.HttpUtils (proxy, isOldHackageURI)
+import Distribution.Client.HttpUtils (isOldHackageURI, cabalBrowse)
 
 import Distribution.Simple.Utils (debug, notice, warn, info)
 import Distribution.Verbosity (Verbosity)
@@ -15,25 +18,21 @@ import qualified Distribution.Client.BuildReports.Anonymous as BuildReport
 import qualified Distribution.Client.BuildReports.Upload as BuildReport
 
 import Network.Browser
-         ( BrowserAction, browse, request
-         , Authority(..), addAuthority, setAuthorityGen
-         , setOutHandler, setErrHandler, setProxy )
+         ( request )
 import Network.HTTP
          ( Header(..), HeaderName(..), findHeader
          , Request(..), RequestMethod(..), Response(..) )
-import Network.TCP (HandleStream)
 import Network.URI (URI(uriPath), parseURI)
 
 import Data.Char        (intToDigit)
 import Numeric          (showHex)
-import System.IO        (hFlush, stdin, stdout, hGetEcho, hSetEcho
-                        ,openBinaryFile, IOMode(ReadMode), hGetContents)
+import System.IO        (hFlush, stdin, stdout, hGetEcho, hSetEcho)
 import Control.Exception (bracket)
 import System.Random    (randomRIO)
 import System.FilePath  ((</>), takeExtension, takeFileName)
 import qualified System.FilePath.Posix as FilePath.Posix (combine)
 import System.Directory
-import Control.Monad (forM_)
+import Control.Monad (forM_, when)
 
 
 --FIXME: how do we find this path for an arbitrary hackage server?
@@ -52,12 +51,7 @@ upload verbosity repos mUsername mPassword paths = do
                           else targetRepoURI{uriPath = uriPath targetRepoURI `FilePath.Posix.combine` "upload"}
           Username username <- maybe promptUsername return mUsername
           Password password <- maybe promptPassword return mPassword
-          let auth = addAuthority AuthBasic {
-                       auRealm    = "Hackage",
-                       auUsername = username,
-                       auPassword = password,
-                       auSite     = uploadURI
-                     }
+          let auth = Just (username, password)
           flip mapM_ paths $ \path -> do
             notice verbosity $ "Uploading " ++ path ++ "... "
             handlePackage verbosity uploadURI auth path
@@ -83,54 +77,40 @@ promptPassword = do
 
 report :: Verbosity -> [Repo] -> Maybe Username -> Maybe Password -> IO ()
 report verbosity repos mUsername mPassword = do
-      let uploadURI = if isOldHackageURI targetRepoURI
-                      then legacyUploadURI
-                      else targetRepoURI{uriPath = ""}
       Username username <- maybe promptUsername return mUsername
       Password password <- maybe promptPassword return mPassword
-      let auth = addAuthority AuthBasic {
-                   auRealm    = "Hackage",
-                   auUsername = username,
-                   auPassword = password,
-                   auSite     = uploadURI
-                 }
+      let auth = Just (username, password)
       forM_ repos $ \repo -> case repoKind repo of
         Left remoteRepo
             -> do dotCabal <- defaultCabalDir
                   let srcDir = dotCabal </> "reports" </> remoteRepoName remoteRepo
-                  contents <- getDirectoryContents srcDir
-                  forM_ (filter (\c -> takeExtension c == ".log") contents) $ \logFile ->
-                      do inp <- readFile (srcDir </> logFile)
-                         let (reportStr, buildLog) = read inp :: (String,String)
-                         case BuildReport.parse reportStr of
-                           Left errs -> do warn verbosity $ "Errors: " ++ errs -- FIXME
-                           Right report' ->
-                               do info verbosity $ "Uploading report for " ++ display (BuildReport.package report')
-                                  browse $ BuildReport.uploadReports (remoteRepoURI remoteRepo) [(report', Just buildLog)] auth
-                                  return ()
+                  -- We don't want to bomb out just because we haven't built any packages from this repo yet
+                  srcExists <- doesDirectoryExist srcDir
+                  when srcExists $ do
+                    contents <- getDirectoryContents srcDir
+                    forM_ (filter (\c -> takeExtension c == ".log") contents) $ \logFile ->
+                        do inp <- readFile (srcDir </> logFile)
+                           let (reportStr, buildLog) = read inp :: (String,String)
+                           case BuildReport.parse reportStr of
+                             Left errs -> do warn verbosity $ "Errors: " ++ errs -- FIXME
+                             Right report' ->
+                                 do info verbosity $ "Uploading report for " ++ display (BuildReport.package report')
+                                    cabalBrowse verbosity auth $ BuildReport.uploadReports (remoteRepoURI remoteRepo) [(report', Just buildLog)]
+                                    return ()
         Right{} -> return ()
-  where
-    targetRepoURI = remoteRepoURI $ last [ remoteRepo | Left remoteRepo <- map repoKind repos ] --FIXME: better error message when no repos are given
 
 check :: Verbosity -> [FilePath] -> IO ()
 check verbosity paths = do
           flip mapM_ paths $ \path -> do
             notice verbosity $ "Checking " ++ path ++ "... "
-            handlePackage verbosity checkURI (return ()) path
+            handlePackage verbosity checkURI Nothing path
 
-handlePackage :: Verbosity -> URI -> BrowserAction (HandleStream String) ()
+handlePackage :: Verbosity -> URI -> Maybe (String, String)
               -> FilePath -> IO ()
 handlePackage verbosity uri auth path =
   do req <- mkRequest uri path
-     p   <- proxy verbosity
      debug verbosity $ "\n" ++ show req
-     (_,resp) <- browse $ do
-                   setProxy p
-                   setErrHandler (warn verbosity . ("http error: "++))
-                   setOutHandler (debug verbosity)
-                   auth
-                   setAuthorityGen (\_ _ -> return Nothing)
-                   request req
+     (_,resp) <- cabalBrowse verbosity auth $ request req
      debug verbosity $ show resp
      case rspCode resp of
        (2,0,0) -> do notice verbosity "Ok"
@@ -140,31 +120,31 @@ handlePackage verbosity uri auth path =
                      case findHeader HdrContentType resp of
                        Just contenttype
                          | takeWhile (/= ';') contenttype == "text/plain"
-                         -> notice verbosity $ rspBody resp
-                       _ -> debug verbosity $ rspBody resp
+                         -> notice verbosity $ B.unpack $ rspBody resp
+                       _ -> debug verbosity $ B.unpack $ rspBody resp
 
-mkRequest :: URI -> FilePath -> IO (Request String)
+mkRequest :: URI -> FilePath -> IO (Request ByteString)
 mkRequest uri path = 
     do pkg <- readBinaryFile path
        boundary <- genBoundary
-       let body = printMultiPart boundary (mkFormData path pkg)
+       let body = printMultiPart (B.pack boundary) (mkFormData path pkg)
        return $ Request {
                          rqURI = uri,
                          rqMethod = POST,
                          rqHeaders = [Header HdrContentType ("multipart/form-data; boundary="++boundary),
-                                      Header HdrContentLength (show (length body)),
+                                      Header HdrContentLength (show (B.length body)),
                                       Header HdrAccept ("text/plain")],
                          rqBody = body
                         }
 
-readBinaryFile :: FilePath -> IO String
-readBinaryFile path = openBinaryFile path ReadMode >>= hGetContents
+readBinaryFile :: FilePath -> IO ByteString
+readBinaryFile = B.readFile
 
 genBoundary :: IO String
 genBoundary = do i <- randomRIO (0x10000000000000,0xFFFFFFFFFFFFFF) :: IO Integer
                  return $ showHex i ""
 
-mkFormData :: FilePath -> String -> [BodyPart]
+mkFormData :: FilePath -> ByteString -> [BodyPart]
 mkFormData path pkg =
   -- yes, web browsers are that stupid (re quoting)
   [BodyPart [Header hdrContentDisposition $
@@ -177,14 +157,17 @@ hdrContentDisposition = HdrCustom "Content-disposition"
 
 -- * Multipart, partly stolen from the cgi package.
 
-data BodyPart = BodyPart [Header] String
+data BodyPart = BodyPart [Header] ByteString
 
-printMultiPart :: String -> [BodyPart] -> String
-printMultiPart boundary xs = 
-    concatMap (printBodyPart boundary) xs ++ crlf ++ "--" ++ boundary ++ "--" ++ crlf
+printMultiPart :: ByteString -> [BodyPart] -> ByteString
+printMultiPart boundary xs =
+    B.concat $ map (printBodyPart boundary) xs ++ [crlf, dd, boundary, dd, crlf]
 
-printBodyPart :: String -> BodyPart -> String
-printBodyPart boundary (BodyPart hs c) = crlf ++ "--" ++ boundary ++ crlf ++ concatMap show hs ++ crlf ++ c
+printBodyPart :: ByteString -> BodyPart -> ByteString
+printBodyPart boundary (BodyPart hs c) = B.concat $ [crlf, dd, boundary, crlf] ++ map (B.pack . show) hs ++ [crlf, c]
 
-crlf :: String
-crlf = "\r\n"
+crlf :: ByteString
+crlf = B.pack "\r\n"
+
+dd :: ByteString
+dd = B.pack "--"
